# Common NB Preprocessors
> A collection of common notebook preprocessors and some useful wrappers.

[![Tests](https://img.shields.io/github/workflow/status/kai-tub/common-nb-preprocessors/CI?color=dark-green&label=%20Tests)](https://github.com/kai-tub/common-nb-preprocessors//actions/workflows/main.yml)
[![Code Coverage](https://img.shields.io/badge/%20Coverage->95%25-%231674b1?style=flat&color=dark-green)](https://github.com/kai-tub/common-nb-preprocessors//blob/main/pyproject.toml)
[![License](https://img.shields.io/pypi/l/common-nb-preprocessors?color=dark-green)](https://github.com/kai-tub/common-nb-preprocessors//blob/main/LICENSE)
[![MyPy Type Checker](https://img.shields.io/badge/%20type_checker-mypy-%231674b1?style=flat&color=dark-green)](http://mypy-lang.org/)
[![Python Versions](https://img.shields.io/pypi/pyversions/common-nb-preprocessors)](https://pypi.org/project/common-nb-preprocessors)
[![PyPI version](https://img.shields.io/pypi/v/common-nb-preprocessors)](https://pypi.org/project/common-nb-preprocessors) <!-- [![Conda Version](https://img.shields.io/conda/vn/conda-forge/common-nb-preprocessors?color=dark-green)](https://anaconda.org/conda-forge/common-nb-preprocessors) -->
[![pdm-managed](https://img.shields.io/badge/pdm-managed-blueviolet)](https://pdm.fming.dev)
[![Auto Release](https://img.shields.io/badge/release-auto.svg?colorA=888888&colorB=blueviolet&label=auto&logo=data:image/png;base64, )](https://github.com/intuit/auto)

You are probably here for the _useful_ wrappers 😉

These wrappers allow you to:
1. Write _magic_ comments inside of your jupyter-notebook code cells
2. Injects them as metadata
3. Returns the notebook node for further processing by [MyST-NB](https://myst-nb.readthedocs.io/en/latest/index.html)

See the [documentation](https://docs.kai-tub.tech/common-nb-preprocessors/) for more details.
